netapp_ontap.models.analytics_histogram_by_time API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.analytics_histogram_by_time`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AnalyticsHistogramByTimeSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AnalyticsHistogramByTime object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `labels GET POST PATCH`

    The labels field of the analytics_histogram_by_time.

  `newest_label GET POST PATCH`

    The newest time label with a non-zero histogram value.

  `oldest_label GET POST PATCH`

    The oldest time label with a non-zero histogram value.

  `percentages GET POST PATCH`

    Percentages for this histogram

    Example: [0.1,11.24,0.18,15.75,0.75,83.5,0]

  `values GET POST PATCH`

    Values for this histogram

    Example: [15925248,1735569408,27672576,2430595072,116105216,12889948160,0]